@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0      ]  4      h      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
+GOOF----LE-8-2.0      ]  4      h`      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
 g  filenameS	f  language/elisp/runtime.scm	g  exportsS	
 g  	nil-value	g  t-value	g  value-slot-module	g  function-slot-module	g  
 elisp-bool	g  
@@ -11,12 +11,12 @@ defspecial	g  prim	
 value-slot	  	!g  
 function-slot	"! 	#g  error	$g  resolve-interface	%g  resolve-module	&g  module-defined?	'g  make-unbound-fluid	(g  module-define!	)g  module-export!	*g  
 module-ref	+g  module-set!	,g  make-syntax-transformer	-, 	., 	/g  macro	0g  $sc-dispatch	10 	20 	3g  any	4333 	5g  
-syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  m-WQElMBgu98cFGTtatEdklf-15276	?>7 	@?88 	Af  l-WQElMBgu98cFGTtatEdklf-15281	Bf  l-WQElMBgu98cFGTtatEdklf-15282	Cf  l-WQElMBgu98cFGTtatEdklf-15283	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  l-WQElMBgu98cFGTtatEdklf-15278	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
+syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  m-@JwjAXO1c$QiXkwmLbdCUf-322	?>7 	@?88 	Af  l-@JwjAXO1c$QiXkwmLbdCUf-327	Bf  l-@JwjAXO1c$QiXkwmLbdCUf-328	Cf  l-@JwjAXO1c$QiXkwmLbdCUf-329	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  l-@JwjAXO1c$QiXkwmLbdCUf-324	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
 define-public	R5QMO 	Sg  syntax-violation	TS 	US 	Vf  -source expression failed to match any pattern	Wg  
 datum->syntax	Xg  map	Yg  identifier?	Zg  
 syntax->datum	[g  identity	\g  string->symbol	]g  
-string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  l-WQElMBgu98cFGTtatEdklf-15307	gf 	h9deg 	i;< 	j88 	kf  l-WQElMBgu98cFGTtatEdklf-15301	lf  l-WQElMBgu98cFGTtatEdklf-15302	mkl 	n9ijm 	of  l-WQElMBgu98cFGTtatEdklf-15298	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
-make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  l-WQElMBgu98cFGTtatEdklf-15321   9de  g  args g  body ;  888  f  l-WQElMBgu98cFGTtatEdklf-15313 f  l-WQElMBgu98cFGTtatEdklf-15314 f  l-WQElMBgu98cFGTtatEdklf-15315   9  f  l-WQElMBgu98cFGTtatEdklf-15310   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  m-WQElMBgu98cFGTtatEdklf-15324 7  88  f  l-WQElMBgu98cFGTtatEdklf-15329 f  l-WQElMBgu98cFGTtatEdklf-15330 f  l-WQElMBgu98cFGTtatEdklf-15331   9    f  l-WQElMBgu98cFGTtatEdklf-15326   9H  8F  5O  5O   C 5     h     ]4	
+string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  l-@JwjAXO1c$QiXkwmLbdCUf-353	gf 	h9deg 	i;< 	j88 	kf  l-@JwjAXO1c$QiXkwmLbdCUf-347	lf  l-@JwjAXO1c$QiXkwmLbdCUf-348	mkl 	n9ijm 	of  l-@JwjAXO1c$QiXkwmLbdCUf-344	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
+make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  l-@JwjAXO1c$QiXkwmLbdCUf-367   9de  g  args g  body ;  888  f  l-@JwjAXO1c$QiXkwmLbdCUf-359 f  l-@JwjAXO1c$QiXkwmLbdCUf-360 f  l-@JwjAXO1c$QiXkwmLbdCUf-361   9  f  l-@JwjAXO1c$QiXkwmLbdCUf-356   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  m-@JwjAXO1c$QiXkwmLbdCUf-370 7  88  f  l-@JwjAXO1c$QiXkwmLbdCUf-375 f  l-@JwjAXO1c$QiXkwmLbdCUf-376 f  l-@JwjAXO1c$QiXkwmLbdCUf-377   9    f  l-@JwjAXO1c$QiXkwmLbdCUf-372   9H  8F  5O  5O   C 5   h     ]4	
 5 4 >  "  G   
 RR R"R#        h      - 1 3  @              g  msg
 			 g  args			  g  filenamef  language/elisp/runtime.scm
