@@ -1,4 +1,4 @@
-GOOF----LE-8-2.01%      ]  4  h2      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  enums	 		g  filenameS	
+GOOF----LE-8-2.01%      ]  4  h,      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  enums	 		g  filenameS	
 f  rnrs/enums.scm	g  pureS	g  versionS	
 	 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  and=>	 	g  call-with-deferred-observers	 	 	g  module-use-interfaces!	 	 	g  current-module	 	 	 g  base	! 
  	"g  
@@ -12,10 +12,10 @@ procedural	(&'
 enum-set=?	8g  enum-set-subset?	9g  enum-set-member?	:g  enum-set->list	;g  enum-set-constructor	<g  enum-set-indexer	=g  enum-set-universe	>g  make-enumeration	?123456789:;<=> 	@g  module-re-export!	A@ 	B@ 	Cg  module-replace!	DC 	EC 	Fg  make-record-type-descriptor	Gg  enum-set	Hg  mutable	Ig  universe	JHI 	Kg  	immutable	Lg  set	MKL 	NJM 	Og  enum-set-rtd	Pg  record-constructor	Qg  "make-record-constructor-descriptor	Rg  
 make-enum-set	Sg  record-accessor	Tg  enum-set-universe-internal	Ug  record-mutator	Vg  enum-set-universe-set!	Wg  enum-set-set	Xg  length	Yg  memq	Zg  	list-copy	[g  lset-intersection	\g  eq?	]g  lset<=	^g  
 lset-union	_g  raise	`g  make-assertion-violation	ag  lset-difference	bg  make-syntax-transformer	cb 	db 	eg  macro	fg  $sc-dispatch	gf 	hf 	ig  any	jg  each-any	kiiji 	lg  
-syntax-object	mg  begin	ng  top	on 	pg  ribcage	qg  dummy	rg  	type-name	sg  symbol	tg  constructor-syntax	uqrst 	vg  m-QADLaw3ThHKV9dQc9343qF-16979	wvn 	xwooo 	yf  l-QADLaw3ThHKV9dQc9343qF-16984	zf  l-QADLaw3ThHKV9dQc9343qF-16985	{f  l-QADLaw3ThHKV9dQc9343qF-16986	|f  l-QADLaw3ThHKV9dQc9343qF-16987	}yz{| 	~pux} 	p  g  x   w  f  l-QADLaw3ThHKV9dQc9343qF-16981   p  o~  g  private   lm  g  
+syntax-object	mg  begin	ng  top	on 	pg  ribcage	qg  dummy	rg  	type-name	sg  symbol	tg  constructor-syntax	uqrst 	vg  m-yuQzIdpGbI0miWzC713dgd-2024	wvn 	xwooo 	yf  l-yuQzIdpGbI0miWzC713dgd-2029	zf  l-yuQzIdpGbI0miWzC713dgd-2030	{f  l-yuQzIdpGbI0miWzC713dgd-2031	|f  l-yuQzIdpGbI0miWzC713dgd-2032	}yz{| 	~pux} 	p  g  x   w  f  l-yuQzIdpGbI0miWzC713dgd-2026   p  o~  g  private   lm  g  
 define-syntax l  g  lambda l  g  s l    l)  g  sym l    g  if l  lY  g  
 syntax->datum l  g  syntax l      g  quote l      g  syntax-violation l  g  symbol->string l  f  not a member of the set l  l    g  _ l  g  ... l    g  let* l  lI  g  syms l          g  quoted-universe l  g  
-datum->syntax l  g  list l          g  quoted-syms l          g  or l  g  every l  l          f  not a subset of the universe l    g  quasisyntax l  l;  l>  g  unsyntax l                    f  -source expression failed to match any patternC 5 hx    ]4	
+datum->syntax l  g  list l          g  quoted-syms l          g  or l  g  every l  l          f  not a subset of the universe l    g  quasisyntax l  l;  l>  g  unsyntax l                    f  -source expression failed to match any patternC 5       hx    ]4	
 
 5 4 >  "  G   45 4 h   @   ] 45 L  68       g  filenamef  rnrs/enums.scm
 	
